package com.heroku.api.connection;

import com.heroku.api.request.Request;

/**
 * Asynchronous version of Connection
 *
 * @param <F> the type of 'Future' that this connection will return
 */
public interface AsyncConnection<F> extends Connection {


    /**
     * Asynchronously execute the given request with, using a different apiKey than the one associated with this connection
     *
     * @param request The request to execute
     * @param <T>     The Type of the Response when parsed by the request, returned by the Future
     * @return A future Response of Type F<T>
     */

    <T> F executeAsync(Request<T> request, String apiKey);

}
